document.addEventListener('DOMContentLoaded', () => {
    const calculateBtn = document.getElementById('calculateBtn');
    const resultContainer = document.getElementById('result');

    calculateBtn.addEventListener('click', () => {
        const savings = parseInt(document.getElementById('savings').value) || 0;
        const clients = parseInt(document.getElementById('clients').value) || 0;
        const skills = parseInt(document.getElementById('skills').value) || 0;

        const riskScore = calculateRiskScore(savings, clients, skills);
        const recommendation = getRecommendation(riskScore);

        resultContainer.style.display = 'block';
        resultContainer.innerHTML = `
            <h3>风险评估结果</h3>
            <p>风险指数: ${riskScore}/100</p>
            <p style="margin-top: 1rem;">${recommendation}</p>
        `;
        
        resultContainer.style.backgroundColor = getRiskColor(riskScore);
    });

    function calculateRiskScore(savings, clients, skills) {
        const savingsScore = Math.min(savings * 2, 40);
        const clientsScore = clients * 10;
        const skillsScore = skills * 10;
        
        return Math.min(100, savingsScore + clientsScore + skillsScore);
    }

    function getRecommendation(score) {
        if (score >= 80) {
            return "您已经做好充分准备！建议可以开始规划转型时间表。";
        } else if (score >= 60) {
            return "状况不错，但还有提升空间。建议先兼职尝试，积累更多经验。";
        } else if (score >= 40) {
            return "风险较高，建议先提升核心竞争力并积累更多储蓄。";
        } else {
            return "目前风险很高，建议继续在现有工作中积累经验和资源。";
        }
    }

    function getRiskColor(score) {
        if (score >= 80) return '#4ade80';
        if (score >= 60) return '#fbbf24';
        if (score >= 40) return '#fb923c';
        return '#ef4444';
    }
});